angular.module('MySeriesQuiz', ['ionic', 'ngCordova', 'MySeriesQuiz.controllers', 'pascalprecht.translate','ngIOS9UIWebViewPatch'])

.run(function ($ionicPlatform, $location, $language, $translate, $login, $ionicHistory, $pushNotification, $rootScope, $cordovaPush) {
    
    if($login.getToken() === undefined || $login.getToken() === '') {
        $ionicHistory.nextViewOptions({
            disableAnimate: true,
            disableBack: true
        });
        $location.path("/login");
    } else {
        if($login.getFbId() !== undefined) {
            var data = {'id' : $login.getFbId()};
            $login.loginFB(data).then(function(result) {
                if(result.message) {
                    $login.setToken(result.token);
                    // set user to device
                    if($pushNotification.hasRegisterDevice()) {
                        $pushNotification.registerUser();
                    }
                    $location.path("/dashboard");
                } else {
                    $login.setFbId('');
                    $login.setToken('');
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $location.path("/login");
                }
            });
        } else {
            $login.login($login.getUsername(), $login.getPassword()).then(function(result) {
                if(result.message) {
                    $login.setToken(result.token);
                    // set user to device
                    if($pushNotification.hasRegisterDevice()) {
                        $pushNotification.registerUser();
                    }
                    $location.path("/dashboard");
                } else {
                    $login.setUsername('');
                    $login.setPassword('');
                    $login.setToken('');
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $location.path("/login");
                }
            });
        }
    }
    
    if($language.getLanguage() !== '' && $language.getLanguage() !== undefined) {
        $translate.use($language.getLanguage());
    } else {
        $language.setLanguage($translate.use());
    }
    
    $ionicPlatform.ready(function () {
        // google analytics
        if(typeof analytics !== "undefined") {
            analytics.startTrackerWithId("UA-3348557-9");
        }
        
        // set push notification
        if (typeof window.PushNotification !== "undefined") {
            if(device.platform == "iOS") {
                var iosConfig = {"badge": true,"sound": true,"alert": true};
                $cordovaPush.register(iosConfig).then(function(deviceToken) {
                    $pushNotification.registerDevice(deviceToken);
                  }, function(err) {});

            } else if(device.platform == "Android") {
                var androidConfig = {"senderID": "464324068885","ecb":"onNotification"};
                $cordovaPush.register(androidConfig).then(function(result) {
                    $pushNotification.registerDevice(window.localStorage['registerDevice']);
                }, function(err) {});
            }
        }
        
        // listen for push notifications
        if(device.platform === "iOS") {
            $rootScope.$on('$cordovaPush:notificationReceived', function(event, notification) {
                if (notification.alert) {
                  navigator.notification.alert(notification.alert);
                }

                if (notification.sound) {
                  var snd = new Media(event.sound);
                  snd.play();
                }

                if (notification.badge) {
                  $cordovaPush.setBadgeNumber(notification.badge).then(function(result) {
                    // Success!
                  }, function(err) {
                    // An error occurred. Show a message to the user
                  });
                }
            });
        }
        
        if (window.StatusBar) {
            StatusBar.styleDefault();
        }
    });
    
    $rootScope.$on('$stateChangeSuccess',  function(event, toState, toParams, fromState, fromParams){
        if(typeof analytics !== "undefined") {
            var value = toState.url;
            for (var k in toParams){
                if (toParams.hasOwnProperty(k)) {
                    value = value.replace(k, toParams[k]);
                }
            }
            analytics.trackView(value);
        }
    });
    
})

.config(function ($stateProvider, $translateProvider, $httpProvider) {
    
    $stateProvider

    .state('login', {
        url: "/login",
        templateUrl: "templates/login.html",
        controller: 'loginCrtl'
    })
    .state('signup', {
        url: "/signup",
        templateUrl: "templates/signup.html",
        controller: 'SignUpCtrl'
    })
    .state('signupFacebook', {
        url: "/signupFacebook/:username",
        templateUrl: "templates/signupFacebook.html",
        controller: 'SignUpCtrl'
    })
    .state('dashboard', {
        url: "/dashboard",
        templateUrl: "templates/dashboard.html",
        controller: 'dashboardCrtl'
    })
    .state('playQuiz', {
        url: "/playQuiz/:quizId/:start",
        templateUrl: "templates/playQuiz.html",
        controller: 'playQuizCrtl'
    })
    .state('newQuiz', {
        url: "/newQuiz/:totalSeries/:totalLives",
        templateUrl: "templates/newQuiz.html",
        controller: 'newQuizCrtl'
    })
    .state('friends', {
        url: "/friends",
        templateUrl: "templates/friends.html",
        controller: 'friendsCrtl'
    })
    .state('quizInfo', {
        url: "/quizInfo/:quizId",
        templateUrl: "templates/quizInfo.html",
        controller: 'quizInfoCtrl'
    })
    .state('quizList', {
        url: "/quizList",
        templateUrl: "templates/quizList.html",
        controller: 'quizListCrtl'
    })
    .state('profile', {
        url: "/profile",
        templateUrl: "templates/profile.html",
        controller: 'profileCrtl'
    })
    .state('profileSeries', {
        url: "/profileSeries",
        templateUrl: "templates/profileSeries.html",
        controller: 'profileSeriesCrtl'
    })
    .state('seriesAdd', {
        url: "/seriesAdd",
        templateUrl: "templates/seriesAdd.html",
        controller: 'seriesAddCtrl'
    })
    .state('seriesAddSignup', {
        url: "/seriesAddSignup",
        templateUrl: "templates/seriesAddSignup.html",
        controller: 'seriesAddCtrl'
    })
    .state('timespentSerie', {
        cache: false,
        url: "/timespentSerie",
        templateUrl: "templates/timespentSerie.html",
        controller: 'timespentSerieCrtl'
    })
    .state('settings', {
        url: "/settings",
        templateUrl: "templates/settings.html",
        controller: 'settingsCrtl'
    })
    .state('buy', {
        url: "/buy",
        templateUrl: "templates/buy.html",
        controller: 'buyCrtl'
    });
    
    
    $httpProvider.defaults.headers.common = {
        'Accept': "application/json, text/plain, */*",
        'Mijnserie-App': '01848b73a54ff46562776e99b1e1e4865c35d5e0',
        'Mijnserie-Platform' : 'ios',
        'Mijnserie-Paid' : false,
        'Mijnserie-Country' : 'nl'
    }

    // translate files
    $translateProvider.translations('en', translation_en);
    $translateProvider.translations('nl', translation_nl);
    $translateProvider.preferredLanguage('nl');
    $translateProvider.fallbackLanguage('nl');
    $translateProvider.useSanitizeValueStrategy('escaped');
})

.filter('html',function($sce){
    return function(input){
        return $sce.trustAsHtml(input);
    }
});

function onNotification(notification) {
    switch(notification.event) {
      case 'registered':
        if (notification.regid.length > 0 ) {
            window.localStorage['registerDevice'] = notification.regid;
        }
        break;

      case 'message':
        // this is the actual push notification. its format depends on the data model from the push server
        // alert(notification.message );
        break;

      case 'error':
        //alert('GCM error = ' + notification.msg);
        break;

      default:
        //alert('An unknown GCM event has occurred');
        break;
    }
};