angular.module('MySeriesQuiz.controllers', ['MySeriesQuiz.service', 'ngStorekit'])

.controller('loginCrtl', function($scope, $translate, $ionicPopup, $state, $login, $ionicHistory, $pushNotification, $cordovaFacebook) {
    
    
    $scope.loginData = {};
    
    var showMessageWrongLogin = function () {
        $translate(['login_title', 'login_wrong_usr']).then(function (translations) {
            $ionicPopup.alert({
                title: translations.login_title,
                template: translations.login_wrong_usr
            }).show();
        });
    }
    
    $scope.doLogin = function() {
        if(!angular.isDefined($scope.loginData.username) || !angular.isDefined($scope.loginData.password) || $scope.loginData.username.trim() == "" || $scope.loginData.password.trim() == ""){
           showMessageWrongLogin();
           return;
        }

        $login.login($scope.loginData.username, $scope.loginData.password).then(function(result) {
            if(result.message) {
                $login.setUsername($scope.loginData.username);
                $login.setPassword($scope.loginData.password);
                $login.setToken(result.token);

                // set user to device
                $pushNotification.registerUser();

                $ionicHistory.nextViewOptions({
                    disableBack: true,
                    historyRoot: true
                });
                $state.go("dashboard");
            } else {
                $login.setUsername('');
                $login.setPassword('');
                $login.setToken('');
                showMessageWrongLogin();
            }
        });
    };
    
    $scope.loginFacebook = function() {
        $cordovaFacebook.login(["public_profile", "email", "user_friends", "user_birthday"]).then(function() {
            $cordovaFacebook.api("me",["public_profile","email"]).then(function(data) {
                $login.setFbId(data['id']);
                $login.loginFB(data).then(function(response) {
                    if(response['message'] === 'register') {
                        $ionicHistory.nextViewOptions({
                            disableBack: true,
                            historyRoot: true
                        });
                        $state.go("signupFacebook",{username: response['username']});
                    } else if(response['message']) {
                        $login.setToken(response.token);
                        $pushNotification.registerUser();
                        
                        $ionicHistory.nextViewOptions({
                            disableBack: true,
                            historyRoot: true
                        });
                        $state.go("dashboard");
                    }
                });
            }, function(error) {
//               alert(error); 
            });
        }, function (error) {
//            alert(error);
        });
    }
    
    $scope.goToExternalForgetPassword = function() {
        $translate(['urlPassword']).then(function (translations) {
            window.open(translations.urlPassword, '_system', 'location=yes');
        });
    }
    
     
})

.controller('dashboardCrtl', function($scope, $quiz, $ionicLoading, $state, $ionicPopover, $translate, $ionicPopup, $interval,$server) {
    $scope.quizOverview = [];
    $scope.loadingDone = false;
    $scope.quizId = 0;
    $scope.username = '';
    $scope.timerLivesLeft = 0;
    $scope.timerLivesLeftDate = '';
    $ionicLoading.show();
    var vartimerLivesLeft = '';
    
    $ionicPopover.fromTemplateUrl('templates/approve_game.html', {
        scope: $scope
    }).then(function(popover) {
        $scope.popover = popover;
    });
    
    
    $scope.$on('$ionicView.beforeLeave', function () {
        ionic.DomUtil.ready(function () {
            if(!$server.isPaid && AdMob) {
                AdMob.hideBanner();
            }
        });
    });
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $quiz.getOverview().then(function(result) {
                $interval.cancel(vartimerLivesLeft);
                $scope.quizOverview = result;
                $scope.loadingDone = true;
                $ionicLoading.hide();
                if($scope.quizOverview['gameInfo']['livesDate']['time'] !== 0) {
                    $scope.timerLivesLeft = $scope.quizOverview['gameInfo']['livesDate']['timeleft'];
                    vartimerLivesLeft = $interval(function() {
                        if ($scope.timerLivesLeft > 0) {
                            $scope.timerLivesLeft = $scope.timerLivesLeft-1;
                            var date = new Date($scope.timerLivesLeft*1000);
                            var minutes = "0" + date.getMinutes();
                            var seconds = "0" + date.getSeconds();
                            $scope.timerLivesLeftDate = minutes.substr(-2) + ':' + seconds.substr(-2);
                        } else {
                            $interval.cancel(vartimerLivesLeft);
                        }
                    }, 1000);
                }
            });
            if(!$server.getPaid() && AdMob) {
                AdMob.createBanner( {
                    adId: admobid.banner, 
                    position: AdMob.AD_POSITION.BOTTOM_CENTER,
                    offsetTopBar: false,
                    isTesting: false,
                    overlap: false, 
                    autoShow: true,
                    bgColor: 'black'
                });
            }
        });
    });
    
    $scope.doRefresh = function() {
        $quiz.getOverview().then(function(result) {
            $interval.cancel(vartimerLivesLeft);
            $scope.quizOverview = result;
            if($scope.quizOverview['gameInfo']['livesDate']['time'] !== 0) {
                $scope.timerLivesLeft = $scope.quizOverview['gameInfo']['livesDate']['timeleft'];
                vartimerLivesLeft = $interval(function() {
                    if ($scope.timerLivesLeft > 0) {
                        $scope.timerLivesLeft = $scope.timerLivesLeft-1;
                        var date = new Date($scope.timerLivesLeft*1000);
                        var minutes = "0" + date.getMinutes();
                        var seconds = "0" + date.getSeconds();
                        $scope.timerLivesLeftDate = minutes.substr(-2) + ':' + seconds.substr(-2);
                    } else {
                        $interval.cancel(vartimerLivesLeft);
                    }
                }, 1000);
            }
        }).finally(function() {
            // Stop the ion-refresher from spinning
            $scope.$broadcast('scroll.refreshComplete');
        });
     }
    
    $scope.playQuiz = function(quizId, approved, username) {
        if(approved === 0) {
            $scope.quizId = quizId;
            $scope.username = username;
            $scope.popover.show();
        } else {
           $state.go("playQuiz", {quizId: quizId, start: false});
        }
    }
    
    $scope.gameApproved = function(quizId) {
        $quiz.approvedQuiz(quizId).then(function(result) {
            $scope.popover.hide();
            if(result === '"error lives"') {
                $translate(['newQuiz_buyLivesTitle','newQuiz_buyLives']).then(function (translations) {
                    $ionicPopup.alert({
                      title: translations.newQuiz_buyLivesTitle,
                      template: translations.newQuiz_buyLives
                    });
                });
            } else {
                $state.go("playQuiz", {quizId: quizId, start: true});
            }
        });
    }
    
    $scope.gameDeclined = function(quizId) {
        $quiz.declineQuiz(quizId).then(function(result) {
            $scope.popover.hide();
        });
    }
    
    $scope.startNewGame = function() {
        var totalSeries = $scope.quizOverview['profileInfo']['totalSeries'];
        var totalLives = $scope.quizOverview['gameInfo']['lives'];
        $state.go("newQuiz", {totalSeries: totalSeries, totalLives: totalLives});
    }
    
    $scope.goToBuy = function() {
        if( /(android)/i.test(navigator.userAgent) ) {
            
        } else {
            $state.go("buy");
        }
    }
     
})

.controller('playQuizCrtl', function($scope, $quiz, $ionicLoading, $state, $stateParams,$interval,$translate,$ionicPopup,$ionicHistory, $server) {
    $scope.quiz = [];
    $scope.loadingDone = false;
    $scope.showInfo = true;
    $scope.startingQuiz = true;
    $scope.disableAnswers = false;
    $scope.showScore = false;
    $scope.timerStart = 5;
    $scope.timerQuestion = 15;
    $scope.showQuestionNumber = 10;
    $scope.rightAnswer = 0;
    $scope.wrongAnswer = 0;
    $scope.usedPowerups = false;
    $scope.isAndroid = ionic.Platform.isAndroid();
    $scope.totals = {
        actors: 0,
        episodes: 0,
        information: 0,
        total: 0,
        bonusTime: 0
    };
    $ionicLoading.show();
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $quiz.getQuiz($stateParams.quizId).then(function(result) {
                $scope.quiz = result;
                $scope.loadingDone = true;
                $ionicLoading.hide();
                
                $scope.startQuiz();
                
            });
            if(!$server.getPaid() && AdMob) {
                AdMob.prepareInterstitial({
                    adId: admobid.interstitial,
                    autoShow: false
                });
            }
        });
    });
    
    $scope.startQuiz = function() {
        $scope.showInfo = true;
        $scope.showCategory = '';
        // timer
        $quiz.startQuiz($stateParams.quizId);
        stop = $interval(function() {
            if ($scope.timerStart > 0) {
              $scope.timerStart = $scope.timerStart-1;
            } else {
                $scope.showInfo = false;
                $scope.startQuestions();
            }
        }, 1000);
    }
    
    $scope.startQuestions = function() {
        $interval.cancel(stop);
        $scope.startingQuiz = false;
        $scope.showQuestion = true;
        $scope.showCategory = 'actors';
        $scope.showQuestionNumber = 0;
        $scope.timeQuestion();
    }
    
    $scope.timeQuestion = function() {
        stopQuestion = $interval(function() {
            if ($scope.timerQuestion > 0) {
              $scope.timerQuestion = $scope.timerQuestion-1;
            } else {
                $quiz.notAnswered($stateParams.quizId, $scope.showCategory, $scope.showQuestionNumber, $scope.quiz['contact']['points']);
                $scope.showNextTimeOut();
            }
        }, 1000);
    }
    
    $scope.showNextTimeOut = function() {
        $interval.cancel(stopQuestion);
        $scope.showBetweenQuistions = true;
        var timeoutSec = 2;
        stopTimeOut = $interval(function() {
            if (timeoutSec > 0) {
              timeoutSec = timeoutSec-1;
            } else {
              $scope.showNextQuestion();
              $scope.rightAnswer = 0;
              $scope.wrongAnswer = 0;
              $scope.usedPowerups = false;
              $scope.showQuestionNumber = $scope.showQuestionNumber+1;
              if($scope.showQuestionNumber === 5) {
                  $scope.showQuestionNumber = 0;
                  if($scope.showCategory === 'actors') {
                      $scope.showCategory = 'episodes';
                  } else if($scope.showCategory === 'episodes') {
                      $scope.showCategory = 'information';
                  } else {
                      $scope.showEndQuiz();
                  }
              }
            }
        }, 1000);
    }
    
    $scope.showNextQuestion = function() {
        $interval.cancel(stopTimeOut);
        $scope.disableAnswers = false;
        $scope.showBetweenQuistions = false;
        $scope.timerQuestion = 15;
        $scope.timeQuestion();
    }
    
    $scope.saveAnswer = function(answerGiven, answer, questionId) {
        $scope.disableAnswers = true;
        if(parseInt(answerGiven) === parseInt(answer)) {
            if($scope.usedPowerups) {
                var bonusTime = 0;
            } else {
                var bonusTime = $scope.timerQuestion;
            }
            $scope.rightAnswer = answerGiven;
            $scope.totals['total'] = $scope.totals['total']+1;
            $scope.totals['bonusTime'] = $scope.totals['bonusTime'] + bonusTime;
            if($scope.showCategory === 'actors') {
                $scope.totals['actors'] = $scope.totals['actors'] +1;
            } else if($scope.showCategory === 'episodes') {
                $scope.totals['episodes'] = $scope.totals['episodes']+1;
            } else {
                $scope.totals['information'] = $scope.totals['information']+1;
            }
        } else {
            $scope.wrongAnswer = answerGiven;
        }
        $quiz.saveAnswer(questionId, answerGiven, bonusTime, $scope.quiz['contact']['points']);
        var showRightAnswerTime = 0;
        showRightAnswer = $interval(function() {
            if (showRightAnswerTime > 0) {
              showRightAnswerTime = showRightAnswerTime-1;
            } else {
                $interval.cancel(showRightAnswer);
                $scope.showNextTimeOut();
            }
        },1000);
    }
    
    $scope.showEndQuiz = function() {
        $interval.cancel(stopQuestion);
        $interval.cancel(stopTimeOut);
        $scope.showCategory = '';
        $scope.showScore = true;
        $scope.showQuestion = false;
        console.log($scope.quiz['score']);
        if(parseInt($scope.quiz['opponent']['answersCorrect']) < parseInt($scope.totals['total'])) {
            $scope.quiz['score']['contactScore'] = parseInt($scope.quiz['score']['contactScore'])+1;
        } else if(parseInt($scope.quiz['opponent']['answersCorrect']) > parseInt($scope.totals['total'])) {
            $scope.quiz['score']['opponentScore'] = parseInt($scope.quiz['score']['opponentScore'])+1;
        } else if(parseInt($scope.quiz['opponent']['answersCorrect']) === parseInt($scope.totals['total'])) {
            if($scope.totals['bonusTime'] > parseInt($scope.quiz['opponent']['answersBonus'])) {
                $scope.quiz['score']['contactScore'] = parseInt($scope.quiz['score']['contactScore'])+1;
            } else if($scope.totals['bonusTime'] < parseInt($scope.quiz['opponent']['answersBonus'])) {
                $scope.quiz['score']['opponentScore'] = parseInt($scope.quiz['score']['opponentScore'])+1;
            }
        }
        var contactScore = parseInt($scope.quiz['score']['contactScore']);
        var oppentScore = parseInt($scope.quiz['score']['opponentScore']);
        var totalPoints = contactScore+oppentScore;
        console.log(100+'*'+ contactScore + '/' + totalPoints);
        console.log(100+'*'+ oppentScore + '/' + totalPoints);
        $scope.quiz['score']['contactPercentage'] = 100*contactScore/totalPoints;
        $scope.quiz['score']['opponentPercentage'] = 100*oppentScore/totalPoints;
        console.log($scope.quiz['score']);
        if(!$server.isPaid && AdMob) {
            AdMob.showInterstitial();
        }
    }
    
    $scope.removeOneAnswer = function(total) {
        if($scope.usedPowerups) {
            $translate(['errorPointsOneTitle','errorPointsOneMessage']).then(function (translations) {
                $ionicPopup.alert({
                  title: translations.errorPointsOneTitle,
                  template: translations.errorPointsOneMessage
                });
            });
        } else {
            
            var number = Math.floor(Math.random() * 3);
            var number2 = 5;
            if(total === 2) {
                if($scope.quiz['contact']['points'] < 5) {
                    $translate(['errorPointsTitle','errorPointsMessage']).then(function (translations) {
                        $ionicPopup.alert({
                          title: translations.errorPointsTitle,
                          template: translations.errorPointsMessage
                        });
                    });
                    return;
                }
                $scope.quiz['contact']['points'] = $scope.quiz['contact']['points']-5;
                do {
                    number2 = Math.floor(Math.random() * 3);
                }
                while(number2 === number);
            } else {
                if($scope.quiz['contact']['points'] < 2) {
                    $translate(['errorPointsTitle','errorPointsMessage']).then(function (translations) {
                        $ionicPopup.alert({
                          title: translations.errorPointsTitle,
                          template: translations.errorPointsMessage
                        });
                    });
                    return;
                }
                $scope.quiz['contact']['points'] = $scope.quiz['contact']['points']-2;
            }
            
            $scope.usedPowerups = true;
            var result = document.getElementsByClassName("hideNumber-"+$scope.showCategory+"-"+$scope.showQuestionNumber);
            for(var i = 0; i < result.length; ++i){
                if(i == number) {
                    result[i].className += ' hide';
                }
                if(i == number2) {
                    result[i].className += ' hide';
                }
            }
        }
    }
    
    $scope.getRandomClassNumber = function(answer, question, category, number) {
        if(parseInt(answer) !== parseInt(question)) {
            var returnItem = 'hideNumber-'+category+"-"+number;
            $scope.getRandomClassNumberIndex = $scope.getRandomClassNumberIndex+1;
            return returnItem;
            
        }
    }
    
    $scope.goToDashboard = function() {
        $ionicHistory.nextViewOptions({
            disableBack: true,
            historyRoot: true
        });
        $state.go("dashboard");
    }
    
    $scope.rematch = function(friendId) {
        $ionicLoading.show();
        $quiz.createQuizFriend(friendId).then(function(result) {
            $ionicLoading.hide();
            if(result === 'error lives') {
                $translate(['errorLivesTitle','errorLivesMessage']).then(function (translations) {
                    $ionicPopup.alert({
                      title: translations.errorLivesTitle,
                      template: translations.errorLivesMessage
                    });
                });
            }
            if(result.message === 'play') {
                $state.go("playQuiz", {quizId: result.quizId, start: true});
            }
        });
    }
})


.controller('newQuizCrtl', function($scope, $quiz, $ionicLoading, $state, $stateParams, $profile, $translate, $ionicPopup, $ionicHistory, $cordovaFacebook, $login) {
    $scope.loadingDone = false;
    $scope.totalSeries = parseInt($stateParams.totalSeries);
    $scope.totalLives = $stateParams.totalLives;
    $scope.friends = [];
    $ionicLoading.show();

    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $profile.getFriends(false).then(function(result) {
                $scope.friends = result;
                $scope.loadingDone = true;
                $ionicLoading.hide();
                if($login.getFbId() !== undefined && $login.getFbId() !== '') {
                    $cordovaFacebook.api("/me/friends?fields=id,name,installed",["public_profile","user_friends"]).then(function(data) {
                        $profile.getFbFriends(data).then(function(result) {
                            console.log(result);
                            $scope.friends = $scope.friends.concat(result);
                        });
                    }, function(data) {
                        console.log('error');
                        console.log(JSON.stringify(data));
                    });
                }
            });
        });
    });
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    
    $scope.createQuizRandom = function() {
        $ionicLoading.show();
        $quiz.createQuizRandom().then(function(result) {
            $ionicLoading.hide();
           if(result.message === 'play') {
                $state.go("playQuiz", {quizId: result.quizId, start: true});
            } else {
                $translate(['errorOpponentTitle','errorOpponentMessage']).then(function (translations) {
                    $ionicPopup.alert({
                      title: translations.errorOpponentTitle,
                      template: translations.errorOpponentMessage
                    });
                });
            }
            
        });
    }
    
    $scope.createQuizFriend = function(friendId, totalSeries) {
        if(totalSeries < 5) {
            $translate(['newQuiz_errorTitle','newQuiz_errorValue']).then(function (translations) {
                    $ionicPopup.alert({
                      title: translations.newQuiz_errorTitle,
                      template: translations.newQuiz_errorValue
                    });
                });
        } else {
            $ionicLoading.show();
            $quiz.createQuizFriend(friendId).then(function(result) {
                $ionicLoading.hide();
                if(result.message === 'play') {
                    $state.go("playQuiz", {quizId: result.quizId, start: true});
                }
            });
        }
    }
    
    $scope.moreFriends = function() {
        $state.go("friends");
    }
})

/* FRIENDS - FRIENDS - FRIENDS - FRIENDS - FRIENDS - FRIENDS - FRIENDS - FRIENDS */
.controller('friendsCrtl', function($profile, $scope, $ionicLoading, $ionicHistory, $translate, $ionicPopup, $quiz, $state, $login, $cordovaFacebook) {
    $scope.loadingDone = false;
    $scope.result = [];
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $profile.getFriends(true).then(function(result) {
                $scope.friends = result;
                $scope.loadingDone = true;
                $ionicLoading.hide();
                if($login.getFbId() !== undefined && $login.getFbId() !== '') {
                    $cordovaFacebook.api("/me/friends?fields=id,name,installed",["public_profile","user_friends"]).then(function(data) {
                        $profile.getFbFriends(data).then(function(result) {
                            console.log(result);
                            $scope.friends = $scope.friends.concat(result);
                        });
                    }, function(data) {
                        console.log('error');
                        console.log(JSON.stringify(data));
                    });
                }
            });
        });
    });
    
    $scope.createQuizFriend = function(friendId, totalSeries) {
        if(totalSeries < 5) {
            $translate(['newQuiz_errorTitle','newQuiz_errorValue']).then(function (translations) {
                    $ionicPopup.alert({
                      title: translations.newQuiz_errorTitle,
                      template: translations.newQuiz_errorValue
                    });
                });
        } else {
            $ionicLoading.show();
            $quiz.createQuizFriend(friendId).then(function(result) {
                $ionicLoading.hide();
                if(result.message === 'play') {
                    $state.go("playQuiz", {quizId: result.quizId, start: true});
                }
            });
        }
    }
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };

})

/* SHOW QUIZ INFO*/
.controller('quizInfoCtrl', function($scope, $quiz, $ionicLoading, $state, $stateParams, $ionicHistory) {
    $ionicLoading.show();
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $quiz.getQuiz($stateParams.quizId).then(function(result) {
                $scope.quiz = result;
                $scope.loadingDone = true;
                $ionicLoading.hide();
            });
        });
    });
    
    $scope.parseInteger = function(intVariable) {
        return parseInt(intVariable);
    }
    
    $scope.rematch = function(friendId) {
        $ionicLoading.show();
        $quiz.createQuizFriend(friendId).then(function(result) {
            $ionicLoading.hide();
            if(result === 'error lives') {
                $translate(['errorLivesTitle','errorLivesMessage']).then(function (translations) {
                    $ionicPopup.alert({
                      title: translations.errorLivesTitle,
                      template: translations.errorLivesMessage
                    });
                });
            }
            if(result.message === 'play') {
                $state.go("playQuiz", {quizId: result.quizId, start: true});
            }
        });
    }
})

/* SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE */
.controller('profileCrtl', function($profile, $scope, $ionicLoading, $state, $ionicHistory) {
    $scope.loadingDone = false;
    $scope.profile = [];
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $profile.getQuizInfo().then(function(result) {
                $scope.profile = result;
                $ionicLoading.hide();
                $scope.loadingDone = true;
            });
        });
    });
    
    $scope.doRefresh = function() {
         $profile.getQuizInfo().then(function(result) {
            $scope.profile = result;
        }).finally(function() {
          $scope.$broadcast('scroll.refreshComplete');
        });
     }
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    
    $scope.showQuiz = function(quizId) {
        $state.go("quizInfo", {quizId: quizId});
    }
    
    $scope.goToSettings = function() {
        $state.go("settings");
    }
    
    $scope.goToMoreGames = function() {
        $state.go('quizList');
    }
})

/* SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE - SHOW PROFILE */
.controller('quizListCrtl', function($profile, $scope, $ionicLoading, $state, $ionicHistory) {
    var page = 0;
    $scope.loadingDone = false;
    $scope.result = [];
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $profile.getQuizzesPlayed(0).then(function(result) {
                $scope.result = result[0];
                $ionicLoading.hide();
                $scope.loadingDone = true;
                page = 1;
            });
        });
    });
    
    $scope.doRefresh = function() {
        $profile.getQuizzesPlayed(0).then(function(result) {
           $scope.result = result[0];
           page = 1;
       }).finally(function() {
         $scope.$broadcast('scroll.refreshComplete');
       });
    }
    
    $scope.loadMore = function() {
        $profile.getQuizzesPlayed(page).then(function(result) {
           $scope.result = result[0];
           page++;
        }).finally(function() {
          $scope.$broadcast('scroll.infiniteScrollComplete');
        });
    };
    
    $scope.loadMoreBoolean = function() {
        return $profile.checkIfThereIsMore();
    };
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    
    $scope.showQuiz = function(quizId) {
        $state.go("quizInfo", {quizId: quizId});
    }

})

/* PROFILE SERIES - PROFILE SERIES - PROFILE SERIES - PROFILE SERIES - PROFILE SERIES - PROFILE SERIES - PROFILE SERIES */
.controller('profileSeriesCrtl', function($profile, $scope, $series, $ionicLoading,$translate, $ionicPopup,$ionicHistory) {
    var page = 0;
    $scope.loadingDone = false;
    $scope.deleteSeries = false;
    $scope.profileInfo = [];
    $scope.profileSeries = [];
    $ionicLoading.show();
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $profile.getProfileSeries(0).then(function(result) {
                $scope.profileInfo = result[1];
                $scope.profileSeries = result[0];
                page = 1;
                $ionicLoading.hide();
                $scope.loadingDone = true;
            });
        });
    });
    
    $scope.doRefresh = function() {
         $profile.getProfileSeries(0).then(function(result) {
            $scope.profileInfo = result[1];
            $scope.profileSeries = result[0];
            page = 1;
        }).finally(function() {
          $scope.$broadcast('scroll.refreshComplete');
        });
     }
     
     $scope.loadMore = function() {
        $profile.getProfileSeries(page).then(function(result) {
           $scope.profileSeries = result[0];
           page++;
        }).finally(function() {
          $scope.$broadcast('scroll.infiniteScrollComplete');
        });
    };
    
    $scope.loadMoreBoolean = function() {
        return $profile.checkIfThereIsMore();
    };
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    
    $scope.toggleDeleteSeries = function() {
        if($scope.deleteSeries) {
            $scope.deleteSeries = false;
        } else {
            $scope.deleteSeries = true;
        }
    }
    
    
    $scope.showConfirmDelete = function(serieId) {
        $translate(['profile_e_dProfile','profile_p_confirmV','profile_confirmN','profile_confirmY']).then(function (translations) {
            var title = translations.profile_e_dProfile;
            var value = translations.profile_p_confirmV;
            var confirmPopup = $ionicPopup.confirm({
                title: title,
                template: value,
                cancelText: translations.profile_confirmN,
                okText: translations.profile_confirmY
            });
            confirmPopup.then(function(res) {
                if(res) {
                    $series.deleteSerie(serieId,'profile');
                } else {
                  // cancel, do nothing
                }
            });
        });
    };
})

/* ADD SERIES SIGNUP - ADD SERIES SIGNUP - ADD SERIES SIGNUP - ADD SERIES SIGNUP - ADD SERIES SIGNUP */
.controller('seriesAddCtrl', function($series, $scope, $ionicLoading, $timeout, $ionicScrollDelegate, $state,$ionicHistory) {
    var page = 0;
    $scope.seriesAdded = [];
    $scope.series = [];
    $scope.searchShow = false;
    $scope.loadingDone = false;
    $scope.searchSerieText = '';
    $ionicLoading.show();
    
    $scope.$on('$ionicView.beforeEnter', function () {
        ionic.DomUtil.ready(function () {
            $series.getSeries(0).then(function(result) {
                $scope.series = result;
                page = 1;
                $ionicLoading.hide();
                $scope.loadingDone = true;
            });
        });
    });
    
    $scope.doRefresh = function() {
         $series.getSeries(0).then(function(result) {
            $scope.series = result;
            $scope.searchSerieText = '';
            $scope.mysearch = '';
            $scope.searchShow = false;
            page = 1;
        }).finally(function() {
          $scope.$broadcast('scroll.refreshComplete');
        });
     }
     
     $scope.loadMore = function() {
        $series.getSeries(page, $scope.searchSerieText).then(function(result) {
           $scope.series = result;
           page++;
        }).finally(function() {
          $scope.$broadcast('scroll.infiniteScrollComplete');
        });
    };
    
    $scope.loadMoreBoolean = function() {
        return $series.checkIfThereIsMore();
    };
    
    $scope.searchSerie = function() {
        if($scope.searchShow) {
            $scope.searchShow = false;
        } else {
            $scope.searchShow = true;
        }
    };
    
    var filterTextTimeout;
    $scope.searchSeries = function(val) {
        if (filterTextTimeout) $timeout.cancel(filterTextTimeout);
        filterTextTimeout = $timeout(function() {
            $series.getSeries(0, val).then(function(result) {
                $scope.series = result;
                $ionicScrollDelegate.scrollTop();
                page++;
             })
            $scope.searchSerieText = val;
        }, 500);
    };
    
    $scope.addSeries = function(serieId) {
        $scope.seriesAdded.push(serieId);
    }
    $scope.delSeries = function(serieId) {
        var index = $scope.seriesAdded.indexOf(serieId);
        $scope.seriesAdded.splice(index, 1);
    }
    
    $scope.nextStapSerieTimespent = function() {
        $series.addSerie($scope.seriesAdded);
        $scope.seriesAdded = [];
        $state.go("timespentSerie");
    }
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
})

/* TIMESPENT SIGN UP - TIMESPENT SIGN UP - TIMESPENT SIGN UP - TIMESPENT SIGN UP - TIMESPENT SIGN UP  */ 
.controller('timespentSerieCrtl', function($timespent, $series, $scope, $ionicLoading, $episode, $ionicHistory ,$state, $ionicScrollDelegate, $ionicPopup, $translate) {
    var serieIds = $series.getLastAddedSeries();
    $scope.timespentSeries = [];
    $scope.timespentIndex = 0;
    $scope.timespentTotal = serieIds.length;
    $scope.timespentSelectOptions = [];
    $scope.timespentSelectId = [];
    $scope.timespentValue = [];
    $scope.timespentValueTotal = {day:0, hour:0, min:0};
    $scope.welcomeMessage = false;
    
    $ionicLoading.show();
    
    $scope.$on('$ionicView.beforeEnter', function() {
        ionic.DomUtil.ready(function () {
            var serieId = serieIds.shift();
            $timespent.getTimespentBySerie(serieId, 0).then(function(result) {
                $scope.timespentSelectOptions = [];
                $scope.timespentSelectId = [];
                $scope.timespentSeries = result;
                $scope.timespentIndex = 0;
                $ionicLoading.hide();
                for (var i = 0; i < serieIds.length; i++) {
                    $timespent.getTimespentBySerie(serieIds[i], 1).then(function(result) {
                        $scope.timespentSeries = result;
                    });
                }
            });
        });
    });
    
    $scope.nextSerie = function() {
        $scope.timespentIndex = $scope.timespentIndex+1;
        if($scope.timespentTotal == $scope.timespentIndex) {
            $scope.welcomeMessage = true;
        }
    };
    
    $scope.previousSerie = function() {
        $scope.timespentIndex = $scope.timespentIndex-1;
    };
    
    $scope.skipStep = function() {
        $translate(['timespent_sureTitle','timespent_cancel','timespent_oke']).then(function (translations) {
            var confirmPopup = $ionicPopup.confirm({
                title: translations.timespent_sureTitle,
                cancelText: translations.timespent_cancel,
                okText: translations.timespent_oke
            });
            confirmPopup.then(function(res) {
                if(res) {
                    $scope.goToDashboard();
                } else {
                  // cancel, do nothing
                }
            });
        });
    }
    
    $scope.seenAll = function(serieId, value) {
        $scope.timespentSelectOptions[serieId] = 'all';
        $scope.timespentValue[serieId] = parseInt(value);
        $scope.nextSerie();
        $episode.seenAll(serieId, 'all');
        $scope.getTotalTimespentValue();
    };
    
    $scope.seenNothing = function(serieId) {
        $scope.timespentSelectOptions[serieId] = 'none';
        $scope.timespentValue[serieId] = 0;
        $scope.nextSerie();
        $episode.seenAll(serieId, 'none');
        $scope.getTotalTimespentValue();
    };
    $scope.seenEpisode = function(serieId, episode, runtime) {
        $scope.timespentSelectOptions[serieId] = 'episode';
        $scope.timespentValue[serieId] = (parseInt(runtime)*parseInt(episode));
        $scope.timespentSelectId[serieId] = parseInt(episode);
        $ionicScrollDelegate.scrollTop();
        $scope.nextSerie();
        $episode.seenAll(serieId, episode);
        $scope.getTotalTimespentValue();
    };
    
    $scope.checkOption = function(serieId, option) {
        if($scope.timespentSelectOptions[serieId] === option) {
            return true;
        } else {
            return false;
        }
    };
    
    $scope.checkOptionEpisode = function(serieId, episode) {
        if($scope.timespentSelectId[serieId] === parseInt(episode)) {
            return true;
        } else {
            return false;
        }
    };
    
    $scope.getTotalTimespentValue = function() {
        var timespentValue = 0;
        for(var i in $scope.timespentValue) {
            timespentValue = timespentValue+$scope.timespentValue[i];
        }
        
        var returnValue = [];
        var total = parseInt(timespentValue);
        returnValue.hour = Math.floor(total/60);
        returnValue.day = Math.floor(returnValue.hour/24);
        returnValue.min = Math.floor(total-(returnValue.hour*60));
        returnValue.hour = Math.floor(returnValue.hour-(24*returnValue.day));

        $scope.timespentValueTotal = returnValue;
    };
    
    $scope.goToDashboard = function() {
        $ionicHistory.nextViewOptions({
            disableBack: true,
            historyRoot: true
        });
        $state.go("dashboard");
    }
})

/* SIGN UP - SIGN UP - SIGN UP - SIGN UP - SIGN UP - SIGN UP - SIGN UP - SIGN UP - SIGN UP - SIGN UP */
.controller('SignUpCtrl', function($scope, $state, $signUp, $timeout, $login, $translate, $stateParams) {
    $scope.showpassword = false;
    $scope.checkUsername = true;
    $scope.messageUsername = '';
    $scope.checkMail = true;
    $scope.messageEmail = '';
    
    var filterTextTimeout;
    $scope.checkUsernameValid = function(val) {
        if (filterTextTimeout) $timeout.cancel(filterTextTimeout);
        filterTextTimeout = $timeout(function() {
             $signUp.checkUsername(val).then(function(result) {
                if(result === 'true') {
                    $scope.checkUsername = true;
                    $scope.messageUsername = '';
                } else {
                    $scope.checkUsername = false;
                    $scope.messageUsername = result.substring(1, result.length-1);;
                }
             });
        }, 500);
    };
    
    var filterTextTimeout;
    $scope.checkEmailValid = function(val) {
        if (filterTextTimeout) $timeout.cancel(filterTextTimeout);
        filterTextTimeout = $timeout(function() {
             $signUp.checkMail(val).then(function(result) {
                if(result === 'true') {
                    $scope.checkMail = true;
                    $scope.messageEmail = '';
                } else {
                    $scope.checkMail = false;
                    $scope.messageEmail = result.substring(1, result.length-1);;
                }
             });
        }, 500);
    };
    
    $scope.signUp = function() {
        $signUp.register(
            $scope.signup.forename,$scope.signup.lastname, $scope.signup.mail, $scope.signup.username, $scope.signup.password
        ).then(function(result) {
            if(result.message) {
                $login.setUsername($scope.signup.username);
                $login.setPassword($scope.signup.password);
                $login.setToken(result.token);
                
                $state.go('seriesAddSignup');
            } else {
                
            }
        });
    };
    
    $scope.signUpFB = function() {
        $signUp.registerFb($scope.username).then(function(result) {
            if(result.message) {
                $login.setToken(result.token);
                
                $state.go('seriesAddSignup');
            }
        });
    }
    
    $scope.goToExternalConditions = function() {
      $translate(['urlConditions']).then(function (translations) {
          window.open(translations.urlConditions, '_system', 'location=yes');
      });
    }
    
    $scope.showPasswordInput = function() {
        if($scope.showpassword) {
            $scope.showpassword = false;
        } else {
            $scope.showpassword = true;
        }
    }
    
    if($stateParams.username !== '') {
        $scope.username = $stateParams.username;
    }
    
})

.controller('settingsCrtl', function($scope, $state, $language, $login, $translate, $ionicHistory) {
    $scope.language = $language.getLanguage();
    
    $scope.changeLanguage = function(language) {
        $language.setLanguage(language);
        $translate.use(language);
    }
    
    $scope.goExternalContact = function() {
        $translate(['urlContactForm']).then(function (translations) {
          window.open(translations.urlContactForm, '_system', 'location=yes');
        });
    }
    
    $scope.logout = function() {
        $login.logout();
        $state.go("login");
    };
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
})

.controller('buyCrtl', function($scope, $storekit, $ionicLoading, $server, $ionicHistory, $quiz) {
    $scope.productPoints = [];
    $scope.productLives = [];
    $scope.productBanner = [];
    $scope.showBanner = true;
    
    var products = ['bannerFree','lives05','lives12','lives25','points10','points25', 'points50'];
    var loadPoints = ['points10','points25', 'points50'];
    var loadLives = ['lives05','lives12', 'lives25'];
    var loadAddFree = ['bannerFree'];
            
    $ionicLoading.show();
    
    $scope.$on('$ionicView.loaded', function() {
        ionic.DomUtil.ready(function () {
            // points
            // Lives
            $storekit.setLogging(false).load(products).then(function (products) {
                var _products = $storekit.getProducts();
                for (var i in _products) {
                    var product = _products[i];
                    for(var i in loadPoints) {
                        if(loadPoints[i] === product['id']) {
                            $scope.productPoints.push(product);
                        }
                    }
                    for(var i in loadLives) {
                        if(loadLives[i] === product['id']) {
                            $scope.productLives.push(product);
                        }
                    }
                    for(var i in loadAddFree) {
                        if(loadAddFree[i] === product['id']) {
                            $scope.productBanner.push(product);
                        }
                    }
                }
                $ionicLoading.hide();
            })
            .catch(function () {
                console.log('no products loaded');
                $ionicLoading.hide();
            });
            if($server.getPaid()) {
                $scope.showBanner = false;
            }
        });
    });
    
    $scope.goBack = function() {
        $ionicHistory.goBack();
    };
    
    $scope.buy = function(productId) {
        $storekit.purchase(productId);
        
        // watch for purchases
        $storekit
        .watchPurchases()
        .then(function () {
            // Not currently used
        }, function (error) {
            // An error occured. Show a message to the user
        }, function (purchase) {
            if (purchase.productId === productId) {
                if (purchase.type === 'purchase') {
                    if(productId === 'lives05') {
                        $scope.addOptions('lives',5,true);
                    }
                    if(productId === 'lives12') {
                        $scope.addOptions('lives',12,true);
                    }
                    if(productId === 'lives25') {
                        $scope.addOptions('lives',25,true);
                    }
                    if(productId === 'points10') {
                        $scope.addOptions('points',10,true);
                    }
                    if(productId === 'points25') {
                        $scope.addOptions('points',25,true);
                    }
                    if(productId === 'points50') {
                        $scope.addOptions('points',50,true);
                    }
                    if(productId === 'bannerFree') {
                        $scope.removeBanners(true);
                    }
                } else if (purchase.type === 'restore') {
                    if(productId === 'lives05') {
                        $scope.addOptions('lives',5,false);
                    }
                    if(productId === 'lives12') {
                        $scope.addOptions('lives',12,false);
                    }
                    if(productId === 'lives25') {
                        $scope.addOptions('lives',25,false);
                    }
                    if(productId === 'points10') {
                        $scope.addOptions('points',10,false);
                    }
                    if(productId === 'points25') {
                        $scope.addOptions('points',25,false);
                    }
                    if(productId === 'points50') {
                        $scope.addOptions('points',50,false);
                    }
                    if(productId === 'bannerFree') {
                        $scope.removeBanners(false);
                    }
                }
            }
        });
    }
    
    
    $scope.addOptions = function(option, value, addValue) {
        $quiz.buyOptions(option, value, addValue);
    }
    
    $scope.removeBanners = function(boolean) {
        if(boolean) {
            $server.setPaid(1);
        } else {
            $server.setPaid(0);
        }
    }
    
})
;