angular.module('MySeriesQuiz.service', [])

.factory('$server',function ($localstorage) {
    return {
        getServer : function () {
            return 'https://www.myseries.tv/_api/app/';
//            return 'http://10.0.0.101/mijnserie/_api/app/';
        },
        getPaid : function() {
            if($localstorage.get('hasPaid') !== undefined && $localstorage.get('hasPaid') === 1) {
                return true;
            } else {
                return false;
            }
        },
        setPaid : function(value) {
            $localstorage.set('hasPaid' , value);
        }
    }
})

.factory('$localstorage', ['$window', function($window) {
  return {
    set: function(key, value) {
      $window.localStorage[key] = value;
    },
    get: function(key, defaultValue) {
      return $window.localStorage[key] || defaultValue;
    },
    setObject: function(key, value) {
      $window.localStorage[key] = JSON.stringify(value);
    },
    getObject: function(key) {
      return JSON.parse($window.localStorage[key] || '{}');
    }
  }
}])

.factory('$login',function ($localstorage,$http,$server) {
    return {
        setUsername : function (username) {
            $localstorage.set('username', username);
        },
        setPassword : function (password) {
            $localstorage.set('password', password);
        },
        setToken : function (token) {
            $localstorage.set('token',token);
        },
        setFbId : function(FBid) {
            $localstorage.set('fbId',FBid);
        },
        getUsername : function () {
            return $localstorage.get('username');
        },
        getPassword : function () {
            return $localstorage.get('password');
        },
        getToken : function () {
            return $localstorage.get('token');
        },
        getFbId : function () {
            return $localstorage.get('fbId');
        },
        login: function(username, password) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'login/',
                data: {username: username, password: password}
            }
            return $http(req).then(function(data){
                return data.data;
            });
        },
        loginFB: function(data) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'login/',
                data: {facebook: data}
            }
            return $http(req).then(function(data){
                return data.data;
            });
        },
        logout: function() {
            $localstorage.set('username', '');
            $localstorage.set('password', '');
            $localstorage.set('token','');
            $localstorage.set('fbId','');
        }
    }
})

.factory('$signUp',function ($http,$server, $login) {
    return {
        register : function (firstname, surname, email, username, password) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'signup/',
                data: {firstname:firstname, surname:surname, email:email, username:username, password:password}
            }
            return $http(req).then(function(data){
                return data.data;
            });
        },
        registerFb : function(username) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'signup_fb/',
                data: {username:username, fbId: $login.getFbId()}
            }
            return $http(req).then(function(data){
                return data.data;
            });
        },
        checkUsername : function(username) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'signup_check/',
                data: {username: username}
            }
            return $http(req).then(function(data){
                return data.data;
            });
        },
        checkMail : function(mail) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'signup_check/',
                data: {email: mail}
            }
            return $http(req).then(function(data){
                return data.data;
            });
        }
    }
})

.factory('$pushNotification',function ($http, $server, $login, $state, $localstorage) {
    return {
        registerDevice : function(deviceId) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'push_notification/',
                data: {deviceId: deviceId}
            };
            return $http(req).then(function(data){
                $localstorage.set('registerDevice', deviceId);
                $localstorage.set('settingEpisodeValue', true);
                $localstorage.set('settingSeasonValue', true);
                return data.data;
            });
        },
        registerUser : function() {
            var deviceId = $localstorage.get('registerDevice');
            var req = {
                method: 'POST',
                url: $server.getServer()+'push_notification/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {deviceId: deviceId}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                $localstorage.set('registerDeviceUser', true);
                return data.data;
            });
        },
        changeOption : function(option, value) {
            var deviceId = $localstorage.get('registerDevice');
            var req = {
                method: 'POST',
                url: $server.getServer()+'push_notification/',
                data: {deviceId: deviceId, option: option, value: value}
            };
            return $http(req).then(function(data){
                return data.data;
            });
        },
        hasRegisterDevice : function() {
            if($localstorage.get('registerDevice') !== undefined) {
                return true;
            } else {
                return false;
            }
        },
        isUserSet : function() {
            if($localstorage.get('registerDeviceUser') !== undefined) {
                return true;
            } else {
                return false;
            }
        }
    }
})

.factory('$language',function ($localstorage) {
    return {
        getLanguage : function() {
            return $localstorage.get('language');
        },
        setLanguage : function(value) {
            $localstorage.set('language', value);
        }
    }
})

.factory('$quiz',function ($http,$server,$login,$state,$ionicHistory) {
    return {
        getOverview : function() {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_overview/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                }
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        getQuiz : function(quizId) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_info/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {quiz: quizId}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        createQuizRandom : function() {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_create/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                }
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        createQuizFriend : function(friendId) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_create/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {friend: friendId}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        saveAnswer : function(quizQuestion, answer, bonusTime, points) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/question_answer/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {quizQuestion: quizQuestion, answer: answer, bonusTime: bonusTime, points: points}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        startQuiz : function(quiz) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_start/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {quiz: quiz}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        notAnswered : function(quiz, category, number, points) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/question_not_answered/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {quiz: quiz, category: category, number: number, points: points}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        approvedQuiz: function(quiz) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_approve/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {quiz: quiz}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        declineQuiz: function(quiz) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_decline/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {quiz: quiz}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        buyOptions: function(option, value, addValue) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_buy_options/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {option: option, value: value, addValue: addValue}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        }
    }
})

.factory('$profile',function ($http, $server, $login, $state, $ionicHistory) {
    var seriesProfile = [];
    var profileInfo = [];
    var loadInfo = {total: 0, result: 25, resultStart: 0};
    var quizzes = [];
    
    return {
        getProfileSeries : function(page) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'series/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {contact: true, orderby: "serie_title ASC", page: page}
            }
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                page = page++;
                loadInfo = data.data.loadInfo;
                if(page === 0) {
                    profileInfo = data.data.profile;
                    seriesProfile = data.data.series;
                } else {
                    seriesProfile = seriesProfile.concat(data.data.series);
                }
                return [seriesProfile, profileInfo, loadInfo];
            });
        },
        getFriends : function(showAll) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_friends/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {showAll: showAll}
            }
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        getFbFriends : function(friends) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_friends_fb/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {data: friends}
            }
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        getQuizInfo : function() {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_profile/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                }
            }
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $ionicHistory.nextViewOptions({
                        disableAnimate: true,
                        disableBack: true
                    });
                    $state.go("login");
                }
                return data.data;
            });
        },
        checkIfThereIsMore : function() {
            if((loadInfo.resultStart+loadInfo.result) < loadInfo.total) {
                return true;
            } else {
                return false;
            }
            
        },
        getQuizzesPlayed : function(page) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'quiz/quiz_games_played/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {page: page}
            }
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                loadInfo = data.data.loadInfo;
                if(page === 0) {
                    quizzes = data.data.quizzes;
                } else {
                    quizzes = quizzes.concat(data.data.quizzes);
                }
                return [quizzes, loadInfo];
            });
        }
    }
})

.factory('$series',function ($http, $server, $login, $state) {
    var series = [];
    var loadInfo = {total: 0, result: 25, resultStart: 0};
    var lastSeriesId = [];
    return {
        getSeries : function(page, search) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'series/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {page: page, search: search}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                page = page++;
                loadInfo = data.data.loadInfo;
                if(page == 0) {
                    series = data.data.series;
                } else {
                    series = series.concat(data.data.series);
                }
                return series;
            });
        },
        checkIfThereIsMore : function() {
            if((loadInfo.resultStart + loadInfo.result) < loadInfo.total) {
                return true;
            } else {
                return false;
            }
            
        },
        deleteSerie : function(serieId, option) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'serie_del/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {serie: serieId, option: option}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                return true;
            });
        },
        addSerie : function(serieId, option) {
            lastSeriesId = serieId;
            var req = {
                method: 'POST',
                url: $server.getServer()+'serie_add/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {serie: serieId, option: option}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                return true;
            });
        },
        getLastAddedSeries: function () {
            return lastSeriesId;
        },
    }
})

.factory('$timespent',function ($http, $server, $login, $state) {
    var series = [];
    
    return {
        getTimespentBySerie : function(serieId, item) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'signup_serie_timespent_serie/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {serie: serieId}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                if(item === 0) {
                    series[0] = data.data;
                } else {
                    var serie = [];
                    serie[0] = data.data;
                    series = series.concat(serie);
                }
                return series;
            });
        }
    }
})

.factory('$episode',function ($http, $server, $login, $state) {
    return {
        seenAll : function(serieId, option) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'episode_seen_all/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {serie: serieId, option: option}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                return data.data;
            });
        },
        seenSeason : function(seasonId, option) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'episode_save_season/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {season: seasonId, option: option}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                return data.data;
            });
        },
        episodeInfo : function(episodeId) {
            var req = {
                method: 'POST',
                url: $server.getServer()+'episode_info/',
                headers: {
                  'Mijnserie-Token': $login.getToken()
                },
                data: {episode: episodeId}
            };
            return $http(req).then(function(data){
                if(data.data === 'home') {
                    $login.logout();
                    $state.go("login");
                }
                return data.data;
            });
        }
    }
})
;